package com.atlassian.elasticsearch.buckler;

import com.atlassian.elasticsearch.buckler.config.AuthConfig;
import org.elasticsearch.common.util.concurrent.ThreadContext;
import org.elasticsearch.transport.*;

class AuthorisedSender implements TransportInterceptor.AsyncSender {

    private final TransportInterceptor.AsyncSender sender;
    private final AuthConfig authConfig;
    private final ThreadContext threadContext;

    public AuthorisedSender(TransportInterceptor.AsyncSender sender, AuthConfig authConfig, ThreadContext threadContext) {
        this.sender = sender;
        this.authConfig = authConfig;
        this.threadContext = threadContext;
    }

    @Override
    public <T extends TransportResponse> void sendRequest(Transport.Connection connection, String action, TransportRequest request, TransportRequestOptions options, TransportResponseHandler<T> handler) {
        if (authConfig.isEnabledForTcp()) {
            String authorization = authConfig.getAuthorization();
            if (threadContext.getHeader("Authorization") == null) {
                threadContext.putHeader("Authorization", authorization);
            }
        }

        sender.sendRequest(connection, action, request, options, handler);
    }
}
